@@ -31,17 +31,19 @@ def data(request):
 
 
 def test_roundtrip_1(data, block_size, block_linked,
-                     content_checksum, compression_level,
-                     store_size):
+                     content_checksum, block_checksum,
+                     compression_level, store_size):
     roundtrip_1(data, block_size, block_linked,
-                content_checksum, compression_level,
-                store_size,
+                content_checksum, block_checksum,
+                compression_level, store_size,
     )
 
 def test_roundtrip_2(data, block_size, block_linked,
-                     content_checksum, compression_level,
-                     auto_flush, store_size):
+                     content_checksum, block_checksum,
+                     compression_level, auto_flush,
+                     store_size):
     roundtrip_2(data, block_size, block_linked,
-                content_checksum, compression_level,
+                content_checksum, block_checksum,
+                compression_level,
                 auto_flush, store_size,
     )
